# Talp Pages

## Please note

**This an alpha release version**, so expect sudden API changes and non-documented features.

## Overview

TALP Pages is a collection of Python scripts to postprocess the `json` outputs of [DLB TALP](https://pm.bsc.es/ftp/dlb/doc/user-guide/intro.html#talp-tracking-application-live-performance) in your project.
We also provide you with exemplary pipelines, which makes it easy to integrate TALP into your CI/CD setup and run Continous Benchmarking without having to code up your own solution.

**We provide:**

- `talp`: A Command line tool to postprocess JSONS generated by TALP.
- `talp_download_artifacts_gitlab` Artifact management: Wrappers for the Gitlab artifacts API to download the history of artifacts.
- Automatic metadata addition to enrich the TALP-generated JSONSs
- A static page you can easily host using GitLab Pages that gives you both **insight** into application performance as well as tracking the performance **evolution** through the history of the code.
- Badges you can add into your repository to view the current parallel effiency of your application as reported by TALP

## Installation

TALP Pages is written in Python (3.9+). We rely on [poetry](https://python-poetry.org/) for packaging.
To use, simply install via:

```pip install talp-pages```

From there you should have the following command-line tools available:

- `talp`
- `talp_download_artifacts_gitlab`

## Documentation

Extensive documentation with examples can be found in our [DLB Readthedocs](https://dlb-docs.readthedocs.io)

## License

TALP Pages is available under the General Public License v3.0.
